@@ -12,7 +12,7 @@ module Twitter
     #
     # @return [Array<Twitter::Size>]
     def photo_sizes
-      Array(@attrs[:photo_sizes]).inject({}) do |object, (key, value)|
+      @attrs.fetch(:photo_sizes, []).inject({}) do |object, (key, value)|
         object[key] = Size.new(value)
         object
       end
