@@ -16,7 +16,7 @@ module Twitter
     # @return [Twitter::GeoResults]
     def initialize(attrs = {})
       @attrs = attrs
-      @collection = Array(@attrs[:result][:places]).collect do |place|
+      @collection = @attrs[:result].fetch(:places, []).collect do |place|
         Place.new(place)
       end
     end
