@@ -2,6 +2,6 @@ require 'twitter/base'
 
 module Twitter
   class Metadata < Twitter::Base
-    attr_reader :result_type
+    attr_reader :iso_language_code, :result_type
   end
 end
