@@ -1,26 +1,24 @@
 require 'equalizer'
-require 'twitter/base'
+require 'twitter/identity'
 
 module Twitter
-  class Place < Twitter::Base
-    attr_reader :attributes, :country, :full_name, :name, :woeid
-    alias_method :woe_id, :woeid
+  class Place < Twitter::Identity
+    attr_reader :attributes, :country, :full_name, :name
+    alias_method :woe_id, :id
+    alias_method :woeid, :id
     object_attr_reader :GeoFactory, :bounding_box
     object_attr_reader :Place, :contained_within
     alias_method :contained?, :contained_within?
     uri_attr_reader :uri
 
-    # @param other [Twitter::Place]
-    # @return [Boolean]
-    def eql?(other)
-      super || instance_of?(other.class) && !woeid.nil? && other.respond_to?(:woeid) && woeid.eql?(other.woeid)
-    end
-
-    # @param other [Twitter::Place]
-    # @return [Boolean]
-    def ==(other)
-      other = coerce(other) if respond_to?(:coerce, true)
-      super || kind_of?(self.class) && !woeid.nil? && other.respond_to?(:woeid) && woeid == other.woeid
+    # Initializes a new place
+    #
+    # @param attrs [Hash]
+    # @raise [ArgumentError] Error raised when supplied argument is missing a :woeid key.
+    # @return [Twitter::Place]
+    def initialize(attrs = {})
+      attrs[:id] ||= attrs.fetch(:woeid)
+      super
     end
 
     # @return [String]
