@@ -92,10 +92,12 @@ module Twitter
       # @return [Twitter::Cursor]
       # @overload memberships(options = {})
       #   @param options [Hash] A customizable set of options.
+      #   @option options [Integer] :count The amount of results to return per page. Defaults to 20. No more than 1000 results will ever be returned in a single page.
       #   @option options [Boolean, String, Integer] :filter_to_owned_lists When set to true, t or 1, will return just lists the authenticating user owns, and the user represented by user_id or screen_name is a member of.
       # @overload memberships(user, options = {})
       #   @param user [Integer, String, Twitter::User] A Twitter user ID, screen name, URI, or object.
       #   @param options [Hash] A customizable set of options.
+      #   @option options [Integer] :count The amount of results to return per page. Defaults to 20. No more than 1000 results will ever be returned in a single page.
       #   @option options [Boolean, String, Integer] :filter_to_owned_lists When set to true, t or 1, will return just lists the authenticating user owns, and the user represented by user_id or screen_name is a member of.
       def memberships(*args)
         cursor_from_response_with_user(:lists, Twitter::List, :get, '/1.1/lists/memberships.json', args)
@@ -477,10 +479,12 @@ module Twitter
       # @param user[Integer, String, Twitter::User] A Twitter user ID, screen_name, or object.
       # @return [Hash]
       def merge_owner!(hash, user)
-        unless hash[:owner_id] || hash[:owner_screen_name]
-          user ||= screen_name
+        return hash if hash[:owner_id] || hash[:owner_screen_name]
+        if user
           merge_user!(hash, user, 'owner')
           hash[:owner_id] = hash.delete(:owner_user_id) unless hash[:owner_user_id].nil?
+        else
+          hash[:owner_id] = user_id
         end
         hash
       end
