@@ -11,6 +11,7 @@ module Twitter
     module Tweets
       include Twitter::REST::Utils
       include Twitter::Utils
+      MAX_TWEETS_PER_REQUEST = 100
 
       # Returns up to 100 of the first retweets of a given tweet
       #
@@ -38,7 +39,7 @@ module Twitter
       # @param options [Hash] A customizable set of options.
       # @option options [Integer] :count Specifies the number of records to retrieve. Must be less than or equal to 100.
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
-      # @option options [Boolean] :ids_only ('false') Only return user ids instead of full user objects.
+      # @option options [Boolean] :ids_only ('false') Only return user IDs instead of full user objects.
       def retweeters_of(tweet, options = {})
         ids_only = !!options.delete(:ids_only)
         retweeters = retweets(tweet, options).collect(&:user)
@@ -62,19 +63,23 @@ module Twitter
 
       # Returns Tweets
       #
-      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/show/:id
+      # @see https://dev.twitter.com/docs/api/1.1/get/statuses/lookup
       # @rate_limited Yes
-      # @authentication Requires user context
-      # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
+      # @authentication Required
       # @return [Array<Twitter::Tweet>] The requested Tweets.
       # @overload statuses(*tweets)
       #   @param tweets [Enumerable<Integer, String, URI, Twitter::Tweet>] A collection of Tweet IDs, URIs, or objects.
       # @overload statuses(*tweets, options)
       #   @param tweets [Enumerable<Integer, String, URI, Twitter::Tweet>] A collection of Tweet IDs, URIs, or objects.
       #   @param options [Hash] A customizable set of options.
+      #   @option options [Symbol, String] :method Requests users via a GET request instead of the standard POST request if set to ':get'.
       #   @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def statuses(*args)
-        parallel_tweets_from_response(:get, '/1.1/statuses/show', args)
+        arguments = Twitter::Arguments.new(args)
+        request_method = arguments.options.delete(:method) || :post
+        flat_pmap(arguments.each_slice(MAX_TWEETS_PER_REQUEST)) do |tweets|
+          perform_with_objects(request_method, '/1.1/statuses/lookup.json', arguments.options.merge(:id => tweets.collect { |u| extract_id(u) }.join(',')), Twitter::Tweet)
+        end
       end
 
       # Destroys the specified Tweets
@@ -92,7 +97,10 @@ module Twitter
       #   @param options [Hash] A customizable set of options.
       #   @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def destroy_status(*args)
-        parallel_tweets_from_response(:post, '/1.1/statuses/destroy', args)
+        arguments = Twitter::Arguments.new(args)
+        pmap(arguments) do |tweet|
+          perform_with_object(:post, "/1.1/statuses/destroy/#{extract_id(tweet)}.json", arguments.options, Twitter::Tweet)
+        end
       end
       alias_method :destroy_tweet, :destroy_status
       deprecate_alias :status_destroy, :destroy_status
@@ -108,12 +116,14 @@ module Twitter
       # @return [Twitter::Tweet] The created Tweet.
       # @param status [String] The text of your status update, up to 140 characters.
       # @param options [Hash] A customizable set of options.
+      # @option options [Boolean, String, Integer] :possibly_sensitive Set to true for content which may not be suitable for every audience.
       # @option options [Twitter::Tweet] :in_reply_to_status An existing status that the update is in reply to.
       # @option options [Integer] :in_reply_to_status_id The ID of an existing status that the update is in reply to.
       # @option options [Float] :lat The latitude of the location this tweet refers to. This option will be ignored unless it is inside the range -90.0 to +90.0 (North is positive) inclusive. It will also be ignored if there isn't a corresponding :long option.
       # @option options [Float] :long The longitude of the location this tweet refers to. The valid ranges for longitude is -180.0 to +180.0 (East is positive) inclusive. This option will be ignored if outside that range, if it is not a number, if geo_enabled is disabled, or if there not a corresponding :lat option.
       # @option options [Twitter::Place] :place A place in the world. These can be retrieved from {Twitter::REST::PlacesAndGeo#reverse_geocode}.
       # @option options [String] :place_id A place in the world. These IDs can be retrieved from {Twitter::REST::PlacesAndGeo#reverse_geocode}.
+      # @option options [String] :media_ids A comma separated list of uploaded media IDs to attach to the Tweet.
       # @option options [String] :display_coordinates Whether or not to put a pin on the exact coordinates a tweet has been sent from.
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def update(status, options = {})
@@ -133,12 +143,14 @@ module Twitter
       # @return [Twitter::Tweet] The created Tweet.
       # @param status [String] The text of your status update, up to 140 characters.
       # @param options [Hash] A customizable set of options.
+      # @option options [Boolean, String, Integer] :possibly_sensitive Set to true for content which may not be suitable for every audience.
       # @option options [Twitter::Tweet] :in_reply_to_status An existing status that the update is in reply to.
       # @option options [Integer] :in_reply_to_status_id The ID of an existing status that the update is in reply to.
       # @option options [Float] :lat The latitude of the location this tweet refers to. This option will be ignored unless it is inside the range -90.0 to +90.0 (North is positive) inclusive. It will also be ignored if there isn't a corresponding :long option.
       # @option options [Float] :long The longitude of the location this tweet refers to. The valid ranges for longitude is -180.0 to +180.0 (East is positive) inclusive. This option will be ignored if outside that range, if it is not a number, if geo_enabled is disabled, or if there not a corresponding :lat option.
       # @option options [Twitter::Place] :place A place in the world. These can be retrieved from {Twitter::REST::PlacesAndGeo#reverse_geocode}.
       # @option options [String] :place_id A place in the world. These IDs can be retrieved from {Twitter::REST::PlacesAndGeo#reverse_geocode}.
+      # @option options [String] :media_ids A comma separated list of uploaded media IDs to attach to the Tweet.
       # @option options [String] :display_coordinates Whether or not to put a pin on the exact coordinates a tweet has been sent from.
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def update!(status, options = {})
@@ -200,6 +212,7 @@ module Twitter
       # @rate_limited No
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
+      # @raise [Twitter::Error::UnacceptableIO] Error when the IO object for the media argument does not have a to_io method.
       # @return [Twitter::Tweet] The created Tweet.
       # @param status [String] The text of your status update, up to 140 characters.
       # @param media [File, Hash] A File object with your picture (PNG, JPEG or GIF)
@@ -214,6 +227,7 @@ module Twitter
       # @option options [String] :display_coordinates Whether or not to put a pin on the exact coordinates a tweet has been sent from.
       # @option options [Boolean, String, Integer] :trim_user Each tweet returned in a timeline will include a user object with only the author's numerical ID when set to true, 't' or 1.
       def update_with_media(status, media, options = {})
+        fail(Twitter::Error::UnacceptableIO.new) unless media.respond_to?(:to_io)
         hash = options.dup
         hash[:in_reply_to_status_id] = hash.delete(:in_reply_to_status).id unless hash[:in_reply_to_status].nil?
         hash[:place_id] = hash.delete(:place).woeid unless hash[:place].nil?
@@ -287,17 +301,6 @@ module Twitter
 
     private
 
-      # @param request_method [Symbol]
-      # @param path [String]
-      # @param args [Array]
-      # @return [Array<Twitter::Tweet>]
-      def parallel_tweets_from_response(request_method, path, args)
-        arguments = Twitter::Arguments.new(args)
-        pmap(arguments) do |tweet|
-          perform_with_object(request_method, path + "/#{extract_id(tweet)}.json", arguments.options, Twitter::Tweet)
-        end
-      end
-
       def post_retweet(tweet, options)
         response = post("/1.1/statuses/retweet/#{extract_id(tweet)}.json", options).body
         Twitter::Tweet.new(response)
