@@ -34,7 +34,7 @@ module Twitter
         request_method = options.size.zero? ? :get : :post
         response = send(request_method.to_sym, '/1.1/account/settings.json', options).body
         # https://dev.twitter.com/issues/59
-        response.update(:trend_location => Array(response[:trend_location]).first)
+        response.update(:trend_location => response.fetch(:trend_location, []).first)
         Twitter::Settings.new(response)
       end
 
@@ -136,19 +136,20 @@ module Twitter
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Array<Twitter::User>] User objects that the authenticating user is blocking.
       # @param options [Hash] A customizable set of options.
-      # @option options [Integer] :page Specifies the page of results to retrieve.
-      def blocking(options = {})
+      # @option options [Boolean, String, Integer] :skip_status Do not include user's Tweets when set to true, 't' or 1.
+      def blocked(options = {})
         perform_with_cursor(:get, '/1.1/blocks/list.json', options, :users, Twitter::User)
       end
+      deprecate_alias :blocking, :blocked
 
-      # Returns an array of numeric user ids the authenticating user is blocking
+      # Returns an array of numeric user IDs the authenticating user is blocking
       #
       # @see https://dev.twitter.com/docs/api/1.1/get/blocks/ids
       # @rate_limited Yes
       # @authentication Requires user context
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Twitter::Cursor] Numeric user IDs the authenticating user is blocking.
-      # @overload block(options = {})
+      # @overload blocked_ids(options = {})
       #   @param options [Hash] A customizable set of options.
       def blocked_ids(*args)
         arguments = Twitter::Arguments.new(args)
@@ -191,7 +192,7 @@ module Twitter
       #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
       #   @param options [Hash] A customizable set of options.
       def block(*args)
-        parallel_user_objects_from_response(:post, '/1.1/blocks/create.json', args)
+        parallel_users_from_response(:post, '/1.1/blocks/create.json', args)
       end
 
       # Un-blocks the users specified by the authenticating user
@@ -207,14 +208,14 @@ module Twitter
       #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
       #   @param options [Hash] A customizable set of options.
       def unblock(*args)
-        parallel_user_objects_from_response(:post, '/1.1/blocks/destroy.json', args)
+        parallel_users_from_response(:post, '/1.1/blocks/destroy.json', args)
       end
 
       # Returns extended information for up to 100 users
       #
       # @see https://dev.twitter.com/docs/api/1.1/get/users/lookup
       # @rate_limited Yes
-      # @authentication Requires user context
+      # @authentication Required
       # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
       # @return [Array<Twitter::User>] The requested users.
       # @overload users(*users)
@@ -223,7 +224,6 @@ module Twitter
       #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
       #   @param options [Hash] A customizable set of options.
       #   @option options [Symbol, String] :method Requests users via a GET request instead of the standard POST request if set to ':get'.
-      #   @option options [Boolean] :include_entities The tweet entities node will be disincluded when set to false.
       def users(*args)
         arguments = Twitter::Arguments.new(args)
         request_method = arguments.options.delete(:method) || :post
@@ -241,19 +241,17 @@ module Twitter
       #   Returns extended information for the authenticated user
       #
       #   @param options [Hash] A customizable set of options.
-      #   @option options [Boolean] :include_entities The tweet entities node will be disincluded when set to false.
       #   @option options [Boolean, String, Integer] :skip_status Do not include user's Tweets when set to true, 't' or 1.
       # @overload user(user, options = {})
       #   Returns extended information for a given user
       #
       #   @param user [Integer, String, Twitter::User] A Twitter user ID, screen name, URI, or object.
       #   @param options [Hash] A customizable set of options.
-      #   @option options [Boolean] :include_entities The tweet entities node will be disincluded when set to false.
       #   @option options [Boolean, String, Integer] :skip_status Do not include user's Tweets when set to true, 't' or 1.
       def user(*args)
         arguments = Twitter::Arguments.new(args)
-        if arguments.last
-          merge_user!(arguments.options, arguments.pop)
+        if arguments.last || user_id?
+          merge_user!(arguments.options, arguments.pop || user_id)
           perform_with_object(:get, '/1.1/users/show.json', arguments.options, Twitter::User)
         else
           verify_credentials(arguments.options)
@@ -305,7 +303,7 @@ module Twitter
       #   @param options [Hash] A customizable set of options.
       #   @option options [Boolean, String, Integer] :skip_status Do not include contributee's Tweets when set to true, 't' or 1.
       def contributees(*args)
-        user_objects_from_response(:get, '/1.1/users/contributees.json', args)
+        users_from_response(:get, '/1.1/users/contributees.json', args)
       end
 
       # Returns an array of users who can contribute to the specified account
@@ -323,7 +321,7 @@ module Twitter
       #   @param options [Hash] A customizable set of options.
       #   @option options [Boolean, String, Integer] :skip_status Do not include contributee's Tweets when set to true, 't' or 1.
       def contributors(*args)
-        user_objects_from_response(:get, '/1.1/users/contributors.json', args)
+        users_from_response(:get, '/1.1/users/contributors.json', args)
       end
 
       # Removes the authenticating user's profile banner image
@@ -375,9 +373,70 @@ module Twitter
       #   @param user [Integer, String, Twitter::User] A Twitter user ID, screen name, URI, or object.
       def profile_banner(*args)
         arguments = Twitter::Arguments.new(args)
-        merge_user!(arguments.options, arguments.pop || screen_name) unless arguments.options[:user_id] || arguments.options[:screen_name]
+        merge_user!(arguments.options, arguments.pop || user_id) unless arguments.options[:user_id] || arguments.options[:screen_name]
         perform_with_object(:get, '/1.1/users/profile_banner.json', arguments.options, Twitter::ProfileBanner)
       end
+
+      # Mutes the users specified by the authenticating user
+      #
+      # @see https://dev.twitter.com/docs/api/1.1/post/mutes/users/create
+      # @rate_limited Yes
+      # @authentication Requires user context
+      # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
+      # @return [Array<Twitter::User>] The muted users.
+      # @overload mute(*users)
+      #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
+      # @overload mute(*users, options)
+      #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
+      #   @param options [Hash] A customizable set of options.
+      def mute(*args)
+        parallel_users_from_response(:post, '/1.1/mutes/users/create.json', args)
+      end
+
+      # Un-mutes the user specified by the authenticating user.
+      #
+      # @see https://dev.twitter.com/docs/api/1.1/post/mutes/users/destroy
+      # @rate_limited Yes
+      # @authentication Requires user context
+      # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
+      # @return [Array<Twitter::User>] The un-muted users.
+      # @overload unmute(*users)
+      #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
+      # @overload unmute(*users, options)
+      #   @param users [Enumerable<Integer, String, Twitter::User>] A collection of Twitter user IDs, screen names, or objects.
+      #   @param options [Hash] A customizable set of options.
+      def unmute(*args)
+        parallel_users_from_response(:post, '/1.1/mutes/users/destroy.json', args)
+      end
+
+      # Returns an array of user objects that the authenticating user is muting
+      #
+      # @see https://dev.twitter.com/docs/api/1.1/get/mutes/users/list
+      # @rate_limited Yes
+      # @authentication Requires user context
+      # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
+      # @return [Array<Twitter::User>] User objects that the authenticating user is muting.
+      # @param options [Hash] A customizable set of options.
+      # @option options [Boolean, String, Integer] :skip_status Do not include user's Tweets when set to true, 't' or 1.
+      def muted(options = {})
+        perform_with_cursor(:get, '/1.1/mutes/users/list.json', options, :users, Twitter::User)
+      end
+      deprecate_alias :muting, :muted
+
+      # Returns an array of numeric user IDs the authenticating user is muting
+      #
+      # @see https://dev.twitter.com/docs/api/1.1/get/mutes/users/ids
+      # @rate_limited Yes
+      # @authentication Requires user context
+      # @raise [Twitter::Error::Unauthorized] Error raised when supplied user credentials are not valid.
+      # @return [Twitter::Cursor] Numeric user IDs the authenticating user is muting
+      # @overload muted_ids(options = {})
+      #   @param options [Hash] A customizable set of options.
+      def muted_ids(*args)
+        arguments = Twitter::Arguments.new(args)
+        merge_user!(arguments.options, arguments.pop)
+        perform_with_cursor(:get, '/1.1/mutes/users/ids.json', arguments.options, :ids)
+      end
     end
   end
 end
